@@ -1,9 +1,19 @@
 use super::MJCarousel;
 use super::MJCarouselChild;
+use crate::mj_carousel_image::{MJCarouselImage, NAME as MJ_CAROUSEL_IMAGE};
 use crate::prelude::parse::{Error, Parsable, Parser};
 use crate::{parse_attribute, parse_child, parse_comment};
 use xmlparser::{StrSpan, Tokenizer};
 
+impl Parsable for MJCarouselChild {
+    fn parse<'a>(tag: StrSpan<'a>, tokenizer: &mut Tokenizer<'a>) -> Result<Self, Error> {
+        match tag.as_str() {
+            MJ_CAROUSEL_IMAGE => Ok(MJCarouselImage::parse(tag, tokenizer)?.into()),
+            _ => Err(Error::UnexpectedElement(tag.start())),
+        }
+    }
+}
+
 #[derive(Debug, Default)]
 struct MJCarouselParser(MJCarousel);
 
