@@ -1,5 +1,5 @@
 use crate::mj_body::MJBodyChild;
-use std::collections::HashMap;
+use crate::prelude::hash::Map;
 
 #[cfg(feature = "json")]
 mod json;
@@ -14,6 +14,6 @@ pub const NAME: &str = "mj-hero";
 
 #[derive(Debug, Default)]
 pub struct MJHero {
-    attributes: HashMap<String, String>,
+    attributes: Map<String, String>,
     children: Vec<MJBodyChild>,
 }
