@@ -74,4 +74,14 @@ mod tests {
         let result = root.render(&opts).unwrap();
         compare(expected, result.as_str());
     }
+
+    #[test]
+    fn in_head() {
+        let opts = Options::default();
+        let template = include_str!("../../resources/compare/success/mj-raw-head.mjml");
+        let expected = include_str!("../../resources/compare/success/mj-raw-head.html");
+        let root = MJML::parse(template.to_string()).unwrap();
+        let result = root.render(&opts).unwrap();
+        compare(expected, result.as_str());
+    }
 }
