@@ -1,14 +1,9 @@
-use super::{MJSocialElement, MJSocialElementChild};
+use super::MJSocialElement;
+use crate::mj_raw::MJRawChild;
 use crate::prelude::parse::{Error, Parsable, Parser};
 use crate::{parse_attribute, parse_child, parse_comment, parse_text};
 use xmlparser::{StrSpan, Tokenizer};
 
-impl Parsable for MJSocialElementChild {
-    fn parse<'a>(tag: StrSpan<'a>, _tokenizer: &mut Tokenizer<'a>) -> Result<Self, Error> {
-        Err(Error::UnexpectedElement(tag.start()))
-    }
-}
-
 #[derive(Debug, Default)]
 struct MJSocialElementParser(MJSocialElement);
 
@@ -21,7 +16,7 @@ impl Parser for MJSocialElementParser {
 
     parse_attribute!();
     parse_comment!();
-    parse_child!(MJSocialElementChild);
+    parse_child!(MJRawChild);
     parse_text!();
 }
 
@@ -30,3 +25,24 @@ impl Parsable for MJSocialElement {
         MJSocialElementParser::default().parse(tokenizer)?.build()
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use crate::mjml::MJML;
+
+    #[test]
+    fn parse_ending_tag() {
+        let template = r#"
+        <mjml>
+          <mj-body>
+            <mj-social>
+              <mj-social-element name="facebook">
+                Share <b>test</b> hi
+              </mj-social-element>
+            </mj-social>
+          </mj-body>
+        </mjml>
+        "#;
+        MJML::parse(template.to_string()).unwrap();
+    }
+}
