@@ -99,6 +99,15 @@ mod tests {
         assert!(root.render(&opts).is_ok());
     }
 
+    #[test]
+    fn template_air_astana() {
+        let opts = Options::default();
+        let template = include_str!("../../resources/template/air-astana.mjml");
+        let expected = include_str!("../../resources/template/air-astana.html");
+        let root = MJML::parse(template.to_string()).unwrap();
+        compare(expected, root.render(&opts).unwrap().as_str());
+    }
+
     #[test]
     #[cfg(feature = "orderedmap")]
     fn stable_output() {
